@@ -15,3 +15,8 @@ def test_conditional():
     assert isinstance(subset, starepandas.STAREDataFrame)
 
 
+def test_geom():
+    countries['geom2'] = countries['geometry']
+    countries.set_geometry('geom2', inplace=True)
+    sdf = starepandas.STAREDataFrame(countries)
+    assert sdf._geometry_column_name == countries._geometry_column_name
\ No newline at end of file
